==> react_image_annotate_ns_workflow-5.0.9.tgz: package/OCR/TaskFormLabel.js <==
import WarningAmberIcon from "@mui/icons-material/WarningAmber";
import { IconButton } from "@mui/material";
import React from "react";
import { handleTooltipMessage } from "../Components/utils";
var labelStyle = {
  width: "90%",
  overflow: "hidden",
  wordBreak: "break-all",
  display: "inline-block",
  textOverflow: "ellipsis",
  whiteSpace: "nowrap"
};
function TaskFormLabel(_ref) {
  var display_label = _ref.display_label,
    isAstrick = _ref.isAstrick,
    _ref$isTooltip = _ref.isTooltip,
    isTooltip = _ref$isTooltip === void 0 ? true : _ref$isTooltip,
    isRequired = _ref.isRequired,
    invalid_show = _ref.invalid_show,
    invalid = _ref.invalid,
    handleInvalid = _ref.handleInvalid;
  return /*#__PURE__*/React.createElement("div", {
    className: "flex justify-between"
  }, /*#__PURE__*/React.createElement("div", {
    className: "flex gap-1 items-start"
  }, /*#__PURE__*/React.createElement("div", {
    className: "flex gap-1 items-center task_formlabel"
  }, /*#__PURE__*/React.createElement("label", {
    className: "form-label",
    title: display_label
  }, display_label), isAstrick ? /*#__PURE__*/React.createElement("span", {
    style: {
      color: "red"
    }
  }, handleTooltipMessage({
    title: "Mandatory field to proceed with Save & Next",
    count: 2,
    isTooltip: true
  })) : isRequired && /*#__PURE__*/React.createElement("span", {
    style: {
      color: "red"
    }
  }, handleTooltipMessage({
    title: "Mandatory field to proceed with Submit",
    count: 1,
    isTooltip: true
  })))), invalid_show ? /*#__PURE__*/React.createElement(IconButton, {
    tabIndex: -1,
    style: {
      width: 22,
      height: 22
    },
    size: "small",
    variant: "outlined",
    onClick: function onClick() {
      handleInvalid(invalid);
    }
  }, /*#__PURE__*/React.createElement(WarningAmberIcon, {
    style: {
      color: invalid ? "#faad14" : "grey",
      marginTop: -8,
      width: 16,
      height: 16
    }
  })) : null);
}
export default TaskFormLabel;

==> react_image_annotate_ns_workflow-6.0.8.tgz: package/OCR/TaskFormLabel.js <==
import WarningAmberIcon from "@mui/icons-material/WarningAmber";
import { IconButton } from "@mui/material";
import React from "react";
import { handleTooltipMessage } from "../Components/utils";
var labelStyle = {
  width: "90%",
  overflow: "hidden",
  wordBreak: "break-all",
  display: "inline-block",
  textOverflow: "ellipsis",
  whiteSpace: "nowrap"
};
function TaskFormLabel(_ref) {
  var display_label = _ref.display_label,
    isAstrick = _ref.isAstrick,
    _ref$isTooltip = _ref.isTooltip,
    isTooltip = _ref$isTooltip === void 0 ? true : _ref$isTooltip,
    isRequired = _ref.isRequired,
    invalid_show = _ref.invalid_show,
    invalid = _ref.invalid,
    handleInvalid = _ref.handleInvalid,
    _ref$className = _ref.className,
    className = _ref$className === void 0 ? "" : _ref$className;
  return /*#__PURE__*/React.createElement("div", {
    className: "flex justify-between"
  }, /*#__PURE__*/React.createElement("div", {
    className: "flex gap-1 items-start"
  }, /*#__PURE__*/React.createElement("div", {
    className: "flex gap-1 items-center task_formlabel"
  }, /*#__PURE__*/React.createElement("label", {
    className: "form-label ".concat(className),
    title: display_label
  }, display_label), isAstrick ? /*#__PURE__*/React.createElement("span", {
    style: {
      color: "red"
    }
  }, handleTooltipMessage({
    title: "Mandatory field to proceed with Save & Next",
    count: 2,
    isTooltip: true
  })) : isRequired && /*#__PURE__*/React.createElement("span", {
    style: {
      color: "red"
    }
  }, handleTooltipMessage({
    title: "Mandatory field to proceed with Submit",
    count: 1,
    isTooltip: true
  })))), invalid_show ? /*#__PURE__*/React.createElement(IconButton, {
    tabIndex: -1,
    style: {
      width: 22,
      height: 22
    },
    size: "small",
    variant: "outlined",
    onClick: function onClick() {
      handleInvalid(invalid);
    }
  }, /*#__PURE__*/React.createElement(WarningAmberIcon, {
    style: {
      color: invalid ? "#faad14" : "grey",
      width: 16,
      height: 16
    }
  })) : null);
}
export default TaskFormLabel;
